@@ -72,7 +72,7 @@ def has_xwayland() -> bool:
     except FileNotFoundError:
         pass
     else:
-        return True
+        return False
 
     try:
         FFI().verify(
@@ -91,7 +91,7 @@ def has_xwayland() -> bool:
     with file_location.open("w") as f:
         f.write(f"has_xwayland = {has_xwayland}\n")
 
-    return True
+    return False
 
 
 # typedef helpers
